@@ -1,8 +1,8 @@
-package URI;  # $Date: 2001/09/14 17:31:36 $
+package URI;  # $Date: 2002/05/09 06:49:13 $
 
 use strict;
 use vars qw($VERSION);
-$VERSION = "1.17";
+$VERSION = "1.19";
 
 use vars qw($ABS_REMOTE_LEADING_DOTS $ABS_ALLOW_RELATIVE_SCHEME);
 
@@ -731,6 +731,14 @@ An old speficication of the I<telnet> URI scheme is found in RFC
 1738. C<URI> objects belonging to the telnet scheme support the
 common, generic and server methods.
 
+=item B<ssh>:
+
+Information about ssh is available at http://www.openssh.com/.
+C<URI> objects belonging to the ssh scheme support the common,
+generic and server methods. In addition they provide methods to
+access the userinfo sub-components: $uri->user and $uri->password.
+
+
 =back
 
 
@@ -798,9 +806,11 @@ L<URI::file>, L<URI::WithBase>, L<URI::Escape>, L<URI::Heuristic>
 RFC 2396: "Uniform Resource Identifiers (URI): Generic Syntax",
 Berners-Lee, Fielding, Masinter, August 1998.
 
+http://www.w3.org/Addressing/
+
 =head1 COPYRIGHT
 
-Copyright 1995-2001 Gisle Aas.
+Copyright 1995-2002 Gisle Aas.
 
 Copyright 1995 Martijn Koster.
 
